@@ -198,7 +198,7 @@ setValidity("nifti", function(object) {
     retval <- c(retval, "datatype not recognized")
   }
   ## bitpix should correspond correctly to datatype
-  if (! identical(object@bitpix, convert.bitpix()[[convert.datatype(object@datatype)]])) {
+  if (object@bitpix != convert.bitpix()[[convert.datatype(object@datatype)]]) {
     retval <- c(retval, "bitpix does not match the datatype")
   }
   ## dim should be non-zero for dim[1] dimensions
@@ -215,7 +215,7 @@ setValidity("nifti", function(object) {
     retval <- c(retval, "range(img) != c(cal_min,cal_max)")
   }
   ## pixdim[0] is required when qform_code != 0
-  if (object@"qform_code" != 0 && identical(object@pixdim[1], 0)) {
+  if (object@"qform_code" != 0 && object@pixdim[1] == 0) {
     retval <- c(retval, "pixdim[1] is required")
   }
   ## pixdim[n] required when dim[n] is required
@@ -227,11 +227,11 @@ setValidity("nifti", function(object) {
     retval <- c(retval, "dim/img mismatch")
   }
   ## vox_offset required for an "n+1" header
-  if (identical(object@"magic", "n+1") && identical(object@"vox_offset", 0)) {
+  if (object@"magic" == "n+1" && object@"vox_offset" == 0) {
     retval <- c(retval, "vox_offset required when magic=\"n+1\"")
   }
   ## magic must be "ni1\0" or "n+1\0"
-  if (!(identical(object@"magic", "n+1") || identical(object@"magic", "ni1"))) {
+  if (! (object@"magic" == "n+1" || object@"magic" == "ni1")) {
     retval <- c(retval, "magic != \"n+1\" and magic != \"ni1\"")
   }
   if (is.null(retval)) {
@@ -301,7 +301,8 @@ setValidity("niftiExtensionSection", function(object) {
 ## setReplaceMethod("hdr", signature(x="nifti", name="character", value="ANY"),
 ##           function(x, name, value) {
 ##             x@name <- value
-##             validObject(x)
+##             validNIfTI <- getValidity(getClassDef("nifti"))
+##             validNIfTI(x)
 ##             x
 ##           })
 
@@ -359,7 +360,8 @@ nifti <- function(img=array(0, dim=rep(1,4)), dim, datatype=2, cal.min=NULL,
   if (getOption("niftiAuditTrail")) {
     audit.trail(obj) <- niftiAuditTrailCreated(call=match.call())
   }
-  validObject(obj)
+  validNIfTI <- getValidity(getClassDef("nifti"))
+  validNIfTI(obj)
   return(obj)
 }
 
@@ -442,7 +444,8 @@ setReplaceMethod("[",
                  signature(x="nifti", i="missing", j="missing", value="array"),
                  function(x, value) {
                    x <- as.nifti(value, x)
-                   validObject(x)
+                   validNIfTI <- getValidity(getClassDef("nifti"))
+                   validNIfTI(x)
                    return(x)
                  })
 
